@@ -34,12 +34,11 @@ def jsoncurl():
         return
     json_input = extract_json_input(args)
     if not json_input:
-        print('json input not found')
-        return
-
-    msg = {'url': url, 'json_input': json_input}
-    print(msg)
-    resp = requests.post(url, json=json_input)
+        resp = requests.get(url)
+    else:        
+        msg = {'url': url, 'json_input': json_input}
+        print(msg)
+        resp = requests.post(url, json=json_input)
 
     try:
         print(resp.json())
